@@ -4,5 +4,5 @@
 
 use Test::Harness;
 # Test::Harness::verbose=1;
-runtests(qw(t/ab_Message.t));
+runtests(qw(t/AppBuilder::Message.t));
 
